package com.engidea.comm;

import java.io.IOException;
import java.io.InputStream;

/*
  WinJcom is a native interface to serial ports in java.
  Copyright 2007 by Damiano Bolla, Jcomm@engidea.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

/**
 * If you want to have an input stream instead of read you can just
 * new PortInputStream(commPort) and you can have an input stream.
 */
public class PortInputStream extends InputStream
  {
  private final CommPort commPort;
  
  public PortInputStream ( CommPort commPort )
    {
    this.commPort = commPort;
    }
    
  public int read() throws IOException
    {
    byte []risul = new byte[1];

    int letti = read(risul);

    if ( letti == 1 ) return risul[0] & 0x00FF;
    
    return letti;
    }

  public int read(byte[] buff) throws IOException
    {
    return read(buff, 0, buff.length );
    }

  public int read(byte[] buff, int offset, int len) throws IOException
    { 
    int letti = commPort.read( buff, offset, len );
    
    if ( letti != len )
      throw new TimeoutException("Timeout len="+len+" letti="+letti);
    
    return letti;
    }

  public synchronized int available() throws IOException
    {   
    return commPort.available();
    }
  }
