package com.engidea.comm;

import java.io.IOException;
import java.io.OutputStream;

/*
  WinJcom is a native interface to serial ports in java.
  Copyright 2007 by Damiano Bolla, Jcomm@engidea.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

/**
 * If you want to have an output stream instead of write you can just
 * new PortOutputStream(commPort) and you can have an output stream.
 */
public class PortOutputStream extends OutputStream
  {
  private final CommPort commPort;
  
  public PortOutputStream (CommPort commPort)
    {
    this.commPort = commPort;
    }
    
  public void write(int val) throws IOException
    {
    byte []value = new byte[1];

    value[0] = (byte)val;
    
    write(value);
    }

  public void write(byte[] buff) throws IOException
    {
    write(buff, 0, buff.length);
    }

  public void write(byte[] buff, int offset, int len) throws IOException
    {
    int written = commPort.write( buff, offset, len);
    
    if ( written != len )
      throw new TimeoutException("Timeout len="+len+" written="+written);
    }

  public void flush() throws IOException
    {
    commPort.flush();
    }
  }
