package com.engidea.comm;

import java.io.IOException;

/*
  WinJcom is a native interface to serial ports in java.
  Copyright 2007 by Damiano Bolla, Jcomm@engidea.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

/**
 * Defines a generic serial port, concrete implementation may have more methods
 * but this should be fairly general.
 */
public abstract class SerialPort extends CommPort
  {

  /**
   * COnstructor needed since portName is final
   * @param portName
   */
  public SerialPort ( String portName )
    {
    super(portName);
    }
    
  public static final int DATABITS_5 = 5;
  public static final int DATABITS_6 = 6;
  public static final int DATABITS_7 = 7;
  public static final int DATABITS_8 = 8;

  public static final int PARITY_NONE = 0;
  public static final int PARITY_ODD = 1;
  public static final int PARITY_EVEN = 2;
  public static final int PARITY_MARK = 3;
  public static final int PARITY_SPACE = 4;

  public static final int STOPBITS_1 = 1;
  public static final int STOPBITS_2 = 2;
  public static final int STOPBITS_1_5 = 3;
  
  
  public static final int FLOWCONTROL_NONE        = 0;
  public static final int FLOWCONTROL_RTSCTS_IN   = 1;
  public static final int FLOWCONTROL_RTSCTS_OUT  = 2;
  public static final int FLOWCONTROL_XONXOFF_IN  = 4;
  public static final int FLOWCONTROL_XONXOFF_OUT = 8;

  public abstract void setSerialPortParams
    (int baudrate, int databits, int stopbits, int parity) throws IOException;

  public abstract int getBaudRate() throws IOException;

  public abstract int getDataBits() throws IOException;

  public abstract int getStopBits() throws IOException;

  public abstract int getParity() throws IOException;

  public abstract void setFlowControlMode(int flowcontrol) throws IOException;

  public abstract int getFlowControlMode() throws IOException;

  public abstract boolean isDTR() throws IOException;

  public abstract void setDTR(boolean state) throws IOException;

  public abstract void setRTS(boolean state) throws IOException;

  public abstract boolean isCTS() throws IOException;

  public abstract boolean isDSR() throws IOException;

  public abstract boolean isCD() throws IOException ;

  public abstract boolean isRI() throws IOException;

  public abstract boolean isRTS() throws IOException;

  public abstract void sendBreak(int duration) throws InterruptedException, IOException;

  public abstract void setEventListener(SerialPortEventListener lsnr);

  public abstract void notifyOnDataAvailable(boolean enable)throws IOException;

  public abstract void notifyOnOutputEmpty(boolean enable)throws IOException;

  public abstract void notifyOnCTS(boolean enable)throws IOException;

  public abstract void notifyOnDSR(boolean enable)throws IOException;

  public abstract void notifyOnRingIndicator(boolean enable)throws IOException;

  public abstract void notifyOnCarrierDetect(boolean enable)throws IOException;

  public abstract void notifyOnOverrunError(boolean enable)throws IOException;

  public abstract void notifyOnParityError(boolean enable)throws IOException;

  public abstract void notifyOnFramingError(boolean enable)throws IOException;

  public abstract void notifyOnBreakInterrupt(boolean enable)throws IOException;
  }
